@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro;
 
 use Mojolicious::Lite;
 
-our $VERSION = '0.000013';
+our $VERSION = '0.000014';
 
 use feature qw( state );
 
@@ -174,11 +174,24 @@ post '/' => sub {
 };
 
 sub _render_response {
-    my $c      = shift;
-    my $params = shift;
+    my $c        = shift;
+    my $response = shift;
+    my $params   = _filter_params($c);
 
-    my $res = uri_object( query => $params );
-    $c->render( text => $res->query, format => 'nvp' );
+    # Echo some params back to make the responses more DRY
+    if (
+        (
+            $params->{TRXTYPE}
+            && ( $params->{TRXTYPE} eq 'A' || $params->{TRXTYPE} eq 'S' )
+        )
+        && $params->{INVNUM}
+        ) {
+        $response->{INVNUM}  = $params->{INVNUM};
+        $response->{INVOICE} = $params->{INVNUM};
+    }
+
+    my $response_as_uri = uri_object( query => $response );
+    $c->render( text => $response_as_uri->query, format => 'nvp' );
 }
 
 sub _filter_params {
@@ -208,7 +221,7 @@ WebService::PayPal::PaymentsAdvanced::Mocker::PayflowPro - A simple app to enabl
 
 =head1 VERSION
 
-version 0.000013
+version 0.000014
 
 =head1 DESCRIPTION
 
